==> haskell-stm-chans-3.0.0.4-9-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-Cr78aZkwhsaHBOCaXlDPX0
key: stm-chans-3.0.0.4-Cr78aZkwhsaHBOCaXlDPX0
license: BSD3
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
author: wren gayle romano, Thomas DuBuisson
exposed: True
indefinite: False
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
abi: f9fcb11b4e96e8b1aa65904df1c750c4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.2.2/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-Cr78aZkwhsaHBOCaXlDPX0
depends:
    base-4.10.1.0 stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x
abi-depends: base-4.10.1.0=35a7f6be752ee4f7385cb5bf28677879
             stm-2.4.5.0-7j9Z9j03i0pHiTKIV2qS3x=ad99cb175fde1a67819ef6519a4015eb
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-chans-3.0.0.4-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-stm-chans.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: stm-chans
version: 3.0.0.4
id: stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
key: stm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
license: BSD-3-Clause
copyright: Copyright (c) 2011--2015 wren gayle romano
maintainer: wren@community.haskell.org
author: wren gayle romano, Thomas DuBuisson
stability: provisional
homepage: http://code.haskell.org/~wren/
synopsis: Additional types of channels for STM.
description:
    Additional types of channels for STM.
category: Concurrency
abi: f54ac4e34b18d9a6d6e746c00f5c10f0
exposed: True
exposed-modules:
    Control.Concurrent.STM.TBChan Control.Concurrent.STM.TBMChan
    Control.Concurrent.STM.TBMQueue Control.Concurrent.STM.TMChan
    Control.Concurrent.STM.TMQueue
import-dirs: /usr/lib/ghc-8.4.2/site-local/stm-chans-3.0.0.4
library-dirs: /usr/lib/ghc-8.4.2/site-local/stm-chans-3.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.2/stm-chans-3.0.0.4
hs-libraries: HSstm-chans-3.0.0.4-1zxsnYr1r3u2n2uZuqSuqq
depends:
    base-4.11.1.0 stm-2.4.5.0
abi-depends: base-4.11.1.0=ecd125f03c784a67b61c9a8f6dd222e4
             stm-2.4.5.0=fc4e40e3aa6203460dfa01934bcd44f0
haddock-interfaces: /usr/share/doc/haskell-stm-chans/html/stm-chans.haddock
haddock-html: /usr/share/doc/haskell-stm-chans/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
